@@ -1,5 +1,4 @@
 """ Concise UUID generation. """
-
 import binascii
 import math
 import os
@@ -9,6 +8,7 @@ import uuid as _uu
 def int_to_string(number, alphabet, padding=None):
     """
     Convert a number to a string, using the given alphabet.
+    The output has the most significant digit first.
     """
     output = ""
     alpha_len = len(alphabet)
@@ -18,16 +18,17 @@ def int_to_string(number, alphabet, padding=None):
     if padding:
         remainder = max(padding - len(output), 0)
         output = output + alphabet[0] * remainder
-    return output
+    return output[::-1]
 
 
 def string_to_int(string, alphabet):
     """
     Convert a string to a number, using the given alphabet.
+    The input is assumed to have the most significant digit first.
     """
     number = 0
     alpha_len = len(alphabet)
-    for char in string[::-1]:
+    for char in string:
         number = number * alpha_len + alphabet.index(char)
     return number
 
@@ -35,8 +36,7 @@ def string_to_int(string, alphabet):
 class ShortUUID(object):
     def __init__(self, alphabet=None):
         if alphabet is None:
-            alphabet = list("23456789ABCDEFGHJKLMNPQRSTUVWXYZ"
-                            "abcdefghijkmnopqrstuvwxyz")
+            alphabet = list("23456789ABCDEFGHJKLMNPQRSTUVWXYZ" "abcdefghijkmnopqrstuvwxyz")
 
         self.set_alphabet(alphabet)
 
@@ -50,20 +50,27 @@ class ShortUUID(object):
 
     def encode(self, uuid, pad_length=None):
         """
-        Encodes a UUID into a string (LSB first) according to the alphabet
-        If leftmost (MSB) bits 0, string might be shorter
+        Encode a UUID into a string (LSB first) according to the alphabet
+
+        If leftmost (MSB) bits are 0, the string might be shorter.
         """
         if pad_length is None:
             pad_length = self._length
         return int_to_string(uuid.int, self._alphabet, padding=pad_length)
 
-    def decode(self, string):
+    def decode(self, string, legacy=False):
         """
-        Decodes a string according to the current alphabet into a UUID
+        Decode a string according to the current alphabet into a UUID
         Raises ValueError when encountering illegal characters
-        or too long string
+        or a too-long string.
+
         If string too short, fills leftmost (MSB) bits with 0.
+
+        Pass `legacy=True` if your UUID was encoded with a ShortUUID version
+        prior to 1.0.0.
         """
+        if legacy:
+            string = string[::-1]
         return _uu.UUID(int=string_to_int(string, self._alphabet))
 
     def uuid(self, name=None, pad_length=None):
@@ -78,12 +85,12 @@ class ShortUUID(object):
 
         # If no name is given, generate a random UUID.
         if name is None:
-            uuid = _uu.uuid4()
-        elif "http" not in name.lower():
-            uuid = _uu.uuid5(_uu.NAMESPACE_DNS, name)
+            u = _uu.uuid4()
+        elif name.lower().startswith(("http://", "https://")):
+            u = _uu.uuid5(_uu.NAMESPACE_URL, name)
         else:
-            uuid = _uu.uuid5(_uu.NAMESPACE_URL, name)
-        return self.encode(uuid, pad_length)
+            u = _uu.uuid5(_uu.NAMESPACE_DNS, name)
+        return self.encode(u, pad_length)
 
     def random(self, length=None):
         """
@@ -94,13 +101,11 @@ class ShortUUID(object):
             length = self._length
 
         random_num = int(binascii.b2a_hex(os.urandom(length)), 16)
-        return int_to_string(
-            random_num, self._alphabet, padding=length
-        )[:length]
+        return int_to_string(random_num, self._alphabet, padding=length)[:length]
 
     def get_alphabet(self):
         """Return the current alphabet used for new UUIDs."""
-        return ''.join(self._alphabet)
+        return "".join(self._alphabet)
 
     def set_alphabet(self, alphabet):
         """Set the alphabet to be used for new UUIDs."""
@@ -112,8 +117,7 @@ class ShortUUID(object):
             self._alphabet = new_alphabet
             self._alpha_len = len(self._alphabet)
         else:
-            raise ValueError("Alphabet with more than "
-                             "one unique symbols required.")
+            raise ValueError("Alphabet with more than " "one unique symbols required.")
 
     def encoded_length(self, num_bytes=16):
         """
