@@ -2,15 +2,20 @@ import os
 import string
 import sys
 import unittest
-import pep8
 from collections import defaultdict
+from uuid import UUID
+from uuid import uuid4
 
-from uuid import UUID, uuid4
+from shortuuid.main import decode
+from shortuuid.main import encode
+from shortuuid.main import get_alphabet
+from shortuuid.main import random
+from shortuuid.main import set_alphabet
+from shortuuid.main import ShortUUID
+from shortuuid.main import uuid
 
 sys.path.insert(0, os.path.abspath(__file__ + "/../.."))
 
-from shortuuid.main import *  # noqa
-
 
 class LegacyShortUUIDTest(unittest.TestCase):
     def test_generation(self):
@@ -20,12 +25,12 @@ class LegacyShortUUIDTest(unittest.TestCase):
         self.assertTrue(20 < len(uuid("example.com/")) < 24)
 
     def test_encoding(self):
-        u = UUID('{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}')
-        self.assertEqual(encode(u), "bYRT25J5s7Bniqr4b58cXC")
+        u = UUID("{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}")
+        self.assertEqual(encode(u), "CXc85b4rqinB7s5J52TRYb")
 
     def test_decoding(self):
-        u = UUID('{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}')
-        self.assertEqual(decode("bYRT25J5s7Bniqr4b58cXC"), u)
+        u = UUID("{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}")
+        self.assertEqual(decode("CXc85b4rqinB7s5J52TRYb"), u)
 
     def test_alphabet(self):
         backup_alphabet = get_alphabet()
@@ -69,13 +74,13 @@ class ClassShortUUIDTest(unittest.TestCase):
 
     def test_encoding(self):
         su = ShortUUID()
-        u = UUID('{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}')
-        self.assertEqual(su.encode(u), "bYRT25J5s7Bniqr4b58cXC")
+        u = UUID("{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}")
+        self.assertEqual(su.encode(u), "CXc85b4rqinB7s5J52TRYb")
 
     def test_decoding(self):
         su = ShortUUID()
-        u = UUID('{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}')
-        self.assertEqual(su.decode("bYRT25J5s7Bniqr4b58cXC"), u)
+        u = UUID("{3b1f8b40-222c-4a6e-b77e-779d5a94e21c}")
+        self.assertEqual(su.decode("CXc85b4rqinB7s5J52TRYb"), u)
 
     def test_random(self):
         su = ShortUUID()
@@ -112,8 +117,7 @@ class ClassShortUUIDTest(unittest.TestCase):
         su1 = ShortUUID()
         self.assertEqual(su1.encoded_length(), 22)
 
-        base64_alphabet = string.ascii_uppercase + \
-            string.ascii_lowercase + string.digits + '+/'
+        base64_alphabet = string.ascii_uppercase + string.ascii_lowercase + string.digits + "+/"
 
         su2 = ShortUUID(base64_alphabet)
         self.assertEqual(su2.encoded_length(), 22)
@@ -125,16 +129,6 @@ class ClassShortUUIDTest(unittest.TestCase):
         su4 = ShortUUID()
         self.assertEqual(su4.encoded_length(num_bytes=8), 11)
 
-    def test_pep8(self):
-        pep8style = pep8.StyleGuide([['statistics', True],
-                                     ['show-sources', True],
-                                     ['repeat', True],
-                                     ['paths', [os.path.dirname(
-                                         os.path.abspath(__file__))]]],
-                                    parse_argv=False)
-        report = pep8style.check_files()
-        assert report.total_errors == 0
-
 
 class ShortUUIDPaddingTest(unittest.TestCase):
     def test_padding(self):
@@ -177,5 +171,5 @@ class ShortUUIDPaddingTest(unittest.TestCase):
         self.assertEqual(uid_lengths[uid_length], num_iterations)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
